@@ -9,10 +9,9 @@ def style_bar_chart(ptl_fig, ytitle=''):
   # Color the bars, need to modify color library with more colors
   i=0
   for bar in ptl_fig.data:
-    if bar.name != 'hide':
       bar.marker = {"color": colors[i % len(colors)]}
-      bar.textposition='auto'
-      bar.textfont={"size": 11, "color": "#FFFFFF", "family": "Graphik, Arial, sans-serif"}
+      bar.textposition='outside'
+      bar.textfont={"size": 11, "color": "#000000", "family": "Graphik, Arial, sans-serif"}
       bar.hoverinfo='text'
       i+=1
 
