@@ -9,7 +9,10 @@ def style_table(df, hl_type=None, n=3, bar_cols=[]):
   styles=[
     dict(selector="th", props=[font_family, font_size, ("color", "#191925"), ("background-color","#F1F2F5"), ("text-align", "center")]),
     dict(selector="tbody", props=[font_family, font_size, ("color", "#333333"), ("background-color","#FFFFFF")]),
-    dict(selector="td", props=[("text-align", "left")])
+    dict(selector="td", props=[("text-align", "right")]),
+    dict(selector="th", props=[("text-align", "right")]),
+    dict(selector="td.col0", props=[("text-align", "left")]),
+    dict(selector="th.col0", props=[("text-align", "left")])
   ]
   s=df.style.hide_index().set_table_styles(styles)
   
